# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/k8s/v1/version_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.k8s.v1 import cluster_pb2 as yandex_dot_cloud_dot_k8s_dot_v1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)yandex/cloud/k8s/v1/version_service.proto\x12\x13yandex.cloud.k8s.v1\x1a\x1cgoogle/api/annotations.proto\x1a!yandex/cloud/k8s/v1/cluster.proto\"\x15\n\x13ListVersionsRequest\"Z\n\x14ListVersionsResponse\x12\x42\n\x12\x61vailable_versions\x18\x01 \x03(\x0b\x32&.yandex.cloud.k8s.v1.AvailableVersions\"c\n\x11\x41vailableVersions\x12<\n\x0frelease_channel\x18\x01 \x01(\x0e\x32#.yandex.cloud.k8s.v1.ReleaseChannel\x12\x10\n\x08versions\x18\x02 \x03(\t2\x97\x01\n\x0eVersionService\x12\x84\x01\n\x04List\x12(.yandex.cloud.k8s.v1.ListVersionsRequest\x1a).yandex.cloud.k8s.v1.ListVersionsResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/managed-kubernetes/v1/versionsBV\n\x17yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8sb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.k8s.v1.version_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.k8s.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/k8s/v1;k8s'
  _VERSIONSERVICE.methods_by_name['List']._options = None
  _VERSIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002!\022\037/managed-kubernetes/v1/versions'
  _globals['_LISTVERSIONSREQUEST']._serialized_start=131
  _globals['_LISTVERSIONSREQUEST']._serialized_end=152
  _globals['_LISTVERSIONSRESPONSE']._serialized_start=154
  _globals['_LISTVERSIONSRESPONSE']._serialized_end=244
  _globals['_AVAILABLEVERSIONS']._serialized_start=246
  _globals['_AVAILABLEVERSIONS']._serialized_end=345
  _globals['_VERSIONSERVICE']._serialized_start=348
  _globals['_VERSIONSERVICE']._serialized_end=499
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.organizationmanager.v1.saml.certificate_pb2
import yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class CertificateServiceStub:
    """A set of methods for managing certificates."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.GetCertificateRequest,
        yandex.cloud.organizationmanager.v1.saml.certificate_pb2.Certificate,
    ]
    """Returns the specified certificate.

    To get the list of available certificates, make a [List] request.
    """

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesRequest,
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesResponse,
    ]
    """Retrieves the list of certificates in the specified federation."""

    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.CreateCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a certificate in the specified federation."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.UpdateCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified certificate."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.DeleteCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified certificate."""

    ListOperations: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsRequest,
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsResponse,
    ]
    """Lists operations for the specified certificate."""

class CertificateServiceAsyncStub:
    """A set of methods for managing certificates."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.GetCertificateRequest,
        yandex.cloud.organizationmanager.v1.saml.certificate_pb2.Certificate,
    ]
    """Returns the specified certificate.

    To get the list of available certificates, make a [List] request.
    """

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesRequest,
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesResponse,
    ]
    """Retrieves the list of certificates in the specified federation."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.CreateCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a certificate in the specified federation."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.UpdateCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified certificate."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.DeleteCertificateRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified certificate."""

    ListOperations: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsRequest,
        yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsResponse,
    ]
    """Lists operations for the specified certificate."""

class CertificateServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing certificates."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.GetCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.saml.certificate_pb2.Certificate, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.saml.certificate_pb2.Certificate]]:
        """Returns the specified certificate.

        To get the list of available certificates, make a [List] request.
        """

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificatesResponse]]:
        """Retrieves the list of certificates in the specified federation."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.CreateCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a certificate in the specified federation."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.UpdateCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified certificate."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.DeleteCertificateRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified certificate."""

    @abc.abstractmethod
    def ListOperations(
        self,
        request: yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsResponse, collections.abc.Awaitable[yandex.cloud.organizationmanager.v1.saml.certificate_service_pb2.ListCertificateOperationsResponse]]:
        """Lists operations for the specified certificate."""

def add_CertificateServiceServicer_to_server(servicer: CertificateServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.billing.v1.service_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetServiceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the service to return.
    To get the service ID, use [ServiceService.List] request.
    """
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___GetServiceRequest = GetServiceRequest

@typing.final
class ListServicesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILTER_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on the [yandex.cloud.billing.v1.Service.id] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListServicesResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results,
    set [page_token] to the [ListServicesResponse.next_page_token]
    returned by a previous list request.
    """
    def __init__(
        self,
        *,
        filter: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListServicesRequest = ListServicesRequest

@typing.final
class ListServicesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SERVICES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListServicesRequest.page_size], use
    [next_page_token] as the value
    for the [ListServicesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.billing.v1.service_pb2.Service]:
        """List of services."""

    def __init__(
        self,
        *,
        services: collections.abc.Iterable[yandex.cloud.billing.v1.service_pb2.Service] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "services", b"services"]) -> None: ...

global___ListServicesResponse = ListServicesResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/cdn/v1/rule.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.cdn.v1 import resource_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_resource__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eyandex/cloud/cdn/v1/rule.proto\x12\x13yandex.cloud.cdn.v1\x1a\"yandex/cloud/cdn/v1/resource.proto\x1a\x1dyandex/cloud/validation.proto\"\x92\x01\n\x04Rule\x12\x12\n\x02id\x18\x01 \x01(\x03\x42\x06\xfa\xc7\x31\x02>0\x12\x1a\n\x04name\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\x0crule_pattern\x18\x03 \x01(\tB\r\xe8\xc7\x31\x01\x8a\xc8\x31\x05<=100\x12\x35\n\x07options\x18\x04 \x01(\x0b\x32$.yandex.cloud.cdn.v1.ResourceOptionsBV\n\x17yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdnb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.cdn.v1.rule_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027yandex.cloud.api.cdn.v1Z;github.com/yandex-cloud/go-genproto/yandex/cloud/cdn/v1;cdn'
  _RULE.fields_by_name['id']._options = None
  _RULE.fields_by_name['id']._serialized_options = b'\372\3071\002>0'
  _RULE.fields_by_name['name']._options = None
  _RULE.fields_by_name['name']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _RULE.fields_by_name['rule_pattern']._options = None
  _RULE.fields_by_name['rule_pattern']._serialized_options = b'\350\3071\001\212\3101\005<=100'
  _globals['_RULE']._serialized_start=123
  _globals['_RULE']._serialized_end=269
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Message(google.protobuf.message.Message):
    """The text descriptions and weights that the model uses to generate an image."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Text describing the image."""
    weight: builtins.float
    """Message weight. Negative values indicate negative messages."""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        weight: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["text", b"text", "weight", b"weight"]) -> None: ...

global___Message = Message

@typing.final
class AspectRatio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WIDTH_RATIO_FIELD_NUMBER: builtins.int
    HEIGHT_RATIO_FIELD_NUMBER: builtins.int
    width_ratio: builtins.int
    """Weight of width in image."""
    height_ratio: builtins.int
    """Weight of height in image."""
    def __init__(
        self,
        *,
        width_ratio: builtins.int = ...,
        height_ratio: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["height_ratio", b"height_ratio", "width_ratio", b"width_ratio"]) -> None: ...

global___AspectRatio = AspectRatio

@typing.final
class ImageGenerationOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIME_TYPE_FIELD_NUMBER: builtins.int
    SEED_FIELD_NUMBER: builtins.int
    ASPECT_RATIO_FIELD_NUMBER: builtins.int
    mime_type: builtins.str
    """MIME type of generated image format."""
    seed: builtins.int
    """Seed for image generation."""
    @property
    def aspect_ratio(self) -> global___AspectRatio:
        """Aspect ratio of generated image."""

    def __init__(
        self,
        *,
        mime_type: builtins.str = ...,
        seed: builtins.int = ...,
        aspect_ratio: global___AspectRatio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["aspect_ratio", b"aspect_ratio"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["aspect_ratio", b"aspect_ratio", "mime_type", b"mime_type", "seed", b"seed"]) -> None: ...

global___ImageGenerationOptions = ImageGenerationOptions



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetSearchIndexFileRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILE_ID_FIELD_NUMBER: builtins.int
    SEARCH_INDEX_ID_FIELD_NUMBER: builtins.int
    file_id: builtins.str
    search_index_id: builtins.str
    def __init__(
        self,
        *,
        file_id: builtins.str = ...,
        search_index_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["file_id", b"file_id", "search_index_id", b"search_index_id"]) -> None: ...

global___GetSearchIndexFileRequest = GetSearchIndexFileRequest

@typing.final
class ListSearchIndexFilesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SEARCH_INDEX_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    search_index_id: builtins.str
    page_size: builtins.int
    page_token: builtins.str
    def __init__(
        self,
        *,
        search_index_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["page_size", b"page_size", "page_token", b"page_token", "search_index_id", b"search_index_id"]) -> None: ...

global___ListSearchIndexFilesRequest = ListSearchIndexFilesRequest

@typing.final
class ListSearchIndexFilesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FILES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    @property
    def files(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2.SearchIndexFile]: ...
    def __init__(
        self,
        *,
        files: collections.abc.Iterable[yandex.cloud.ai.assistants.v1.searchindex.search_index_file_pb2.SearchIndexFile] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["files", b"files", "next_page_token", b"next_page_token"]) -> None: ...

global___ListSearchIndexFilesResponse = ListSearchIndexFilesResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.struct_pb2
import google.protobuf.timestamp_pb2
import google.protobuf.wrappers_pb2
import sys
import typing
import yandex.cloud.datasphere.v2.project_pb2
import yandex.cloud.datasphere.v2.resource_types_pb2
import yandex.cloud.datasphere.v2.restrictions_pb2

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ExecutionStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExecutionStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExecutionStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    EXECUTION_STATUS_UNSPECIFIED: _ExecutionStatus.ValueType  # 0
    OK: _ExecutionStatus.ValueType  # 1
    """Execution finished successfully."""
    ERROR: _ExecutionStatus.ValueType  # 2
    """Execution ended with error."""
    ABORTED: _ExecutionStatus.ValueType  # 3
    """Execution was aborted."""

class ExecutionStatus(_ExecutionStatus, metaclass=_ExecutionStatusEnumTypeWrapper): ...

EXECUTION_STATUS_UNSPECIFIED: ExecutionStatus.ValueType  # 0
OK: ExecutionStatus.ValueType  # 1
"""Execution finished successfully."""
ERROR: ExecutionStatus.ValueType  # 2
"""Execution ended with error."""
ABORTED: ExecutionStatus.ValueType  # 3
"""Execution was aborted."""
global___ExecutionStatus = ExecutionStatus

@typing.final
class CreateProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community to create a project in."""
    name: builtins.str
    """Name of the project. 0-63 characters long."""
    description: builtins.str
    """Description of the project. 0-256 characters long."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the project."""

    @property
    def settings(self) -> yandex.cloud.datasphere.v2.project_pb2.Project.Settings:
        """Settings of the project."""

    @property
    def limits(self) -> yandex.cloud.datasphere.v2.project_pb2.Project.Limits:
        """Limits of the project."""

    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: yandex.cloud.datasphere.v2.project_pb2.Project.Settings | None = ...,
        limits: yandex.cloud.datasphere.v2.project_pb2.Project.Limits | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["limits", b"limits", "settings", b"settings"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "description", b"description", "labels", b"labels", "limits", b"limits", "name", b"name", "settings", b"settings"]) -> None: ...

global___CreateProjectRequest = CreateProjectRequest

@typing.final
class CreateProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being created."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___CreateProjectMetadata = CreateProjectMetadata

@typing.final
class UpdateProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    PROJECT_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    LIMITS_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to update.
    To get the project ID use a [ProjectService.List] request.
    """
    name: builtins.str
    """Name of the project. 0-63 characters long."""
    description: builtins.str
    """Description of the project. 0-256 characters long."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the Project resource are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels of the project."""

    @property
    def settings(self) -> yandex.cloud.datasphere.v2.project_pb2.Project.Settings:
        """Settings of the project."""

    @property
    def limits(self) -> yandex.cloud.datasphere.v2.project_pb2.Project.Limits:
        """Limits of the project."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        settings: yandex.cloud.datasphere.v2.project_pb2.Project.Settings | None = ...,
        limits: yandex.cloud.datasphere.v2.project_pb2.Project.Limits | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["limits", b"limits", "settings", b"settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "labels", b"labels", "limits", b"limits", "name", b"name", "project_id", b"project_id", "settings", b"settings", "update_mask", b"update_mask"]) -> None: ...

global___UpdateProjectRequest = UpdateProjectRequest

@typing.final
class UpdateProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being updated."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___UpdateProjectMetadata = UpdateProjectMetadata

@typing.final
class DeleteProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to delete.
    To get the project ID use a [ProjectService.List] request.
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___DeleteProjectRequest = DeleteProjectRequest

@typing.final
class DeleteProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being deleted."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___DeleteProjectMetadata = DeleteProjectMetadata

@typing.final
class OpenProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to open.
    To get the project ID use a [ProjectService.List] request.
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___OpenProjectRequest = OpenProjectRequest

@typing.final
class OpenProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _OpenProjectStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _OpenProjectStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[OpenProjectMetadata._OpenProjectStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        OPEN_PROJECT_STATUS_UNSPECIFIED: OpenProjectMetadata._OpenProjectStatus.ValueType  # 0
        OPEN_PROJECT_STATUS_CLOSING_IDE: OpenProjectMetadata._OpenProjectStatus.ValueType  # 1
        """Closing previous IDE instance."""
        OPEN_PROJECT_STATUS_UNZIPPING_PROJECT: OpenProjectMetadata._OpenProjectStatus.ValueType  # 2
        """Unzipping project."""
        OPEN_PROJECT_STATUS_ALLOCATING_VM: OpenProjectMetadata._OpenProjectStatus.ValueType  # 3
        """Allocating VM for the project."""
        OPEN_PROJECT_STATUS_ALLOCATING_RESOURCES: OpenProjectMetadata._OpenProjectStatus.ValueType  # 4
        """Allocating resources for the project."""
        OPEN_PROJECT_STATUS_STARTING_IDE: OpenProjectMetadata._OpenProjectStatus.ValueType  # 5
        """Starting IDE."""
        OPEN_PROJECT_STATUS_APPLYING_CHECKPOINT: OpenProjectMetadata._OpenProjectStatus.ValueType  # 6
        """Applying checkpoint to project."""
        OPEN_PROJECT_STATUS_UNKNOWN: OpenProjectMetadata._OpenProjectStatus.ValueType  # 7
        """Unknown open project status."""

    class OpenProjectStatus(_OpenProjectStatus, metaclass=_OpenProjectStatusEnumTypeWrapper): ...
    OPEN_PROJECT_STATUS_UNSPECIFIED: OpenProjectMetadata.OpenProjectStatus.ValueType  # 0
    OPEN_PROJECT_STATUS_CLOSING_IDE: OpenProjectMetadata.OpenProjectStatus.ValueType  # 1
    """Closing previous IDE instance."""
    OPEN_PROJECT_STATUS_UNZIPPING_PROJECT: OpenProjectMetadata.OpenProjectStatus.ValueType  # 2
    """Unzipping project."""
    OPEN_PROJECT_STATUS_ALLOCATING_VM: OpenProjectMetadata.OpenProjectStatus.ValueType  # 3
    """Allocating VM for the project."""
    OPEN_PROJECT_STATUS_ALLOCATING_RESOURCES: OpenProjectMetadata.OpenProjectStatus.ValueType  # 4
    """Allocating resources for the project."""
    OPEN_PROJECT_STATUS_STARTING_IDE: OpenProjectMetadata.OpenProjectStatus.ValueType  # 5
    """Starting IDE."""
    OPEN_PROJECT_STATUS_APPLYING_CHECKPOINT: OpenProjectMetadata.OpenProjectStatus.ValueType  # 6
    """Applying checkpoint to project."""
    OPEN_PROJECT_STATUS_UNKNOWN: OpenProjectMetadata.OpenProjectStatus.ValueType  # 7
    """Unknown open project status."""

    PROJECT_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project that is being opened."""
    status: global___OpenProjectMetadata.OpenProjectStatus.ValueType
    """Project opening status."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        status: global___OpenProjectMetadata.OpenProjectStatus.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "status", b"status"]) -> None: ...

global___OpenProjectMetadata = OpenProjectMetadata

@typing.final
class OpenProjectResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_URL_FIELD_NUMBER: builtins.int
    SESSION_TOKEN_FIELD_NUMBER: builtins.int
    project_url: builtins.str
    """URL of the project that is being opened.
    Make GET request to [project_url] with sessionToken query parameter equals to [session_token]
    or POST request to [project_url] with sessionToken body parameter equals to [session_token]
    to fetch DataSphere web interface.
    """
    session_token: builtins.str
    """Session token of the project that is being opened."""
    def __init__(
        self,
        *,
        project_url: builtins.str = ...,
        session_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_url", b"project_url", "session_token", b"session_token"]) -> None: ...

global___OpenProjectResponse = OpenProjectResponse

@typing.final
class GetProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the Project resource to return.
    To get the project ID use a [ProjectService.List] request.
    """
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___GetProjectRequest = GetProjectRequest

@typing.final
class ListProjectsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMUNITY_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PROJECT_NAME_PATTERN_FIELD_NUMBER: builtins.int
    OWNED_BY_ID_FIELD_NUMBER: builtins.int
    community_id: builtins.str
    """ID of the community to list projects in."""
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListProjectsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set [page_token] to the
    [ListProjectsResponse.next_page_token] returned by a previous list request.
    """
    project_name_pattern: builtins.str
    """Name pattern to filter projects that are returned.
    Only projects with names matching the pattern will be returned.
    """
    owned_by_id: builtins.str
    """User ID to filter projects that are returned.
    Only projects that are owned by specified user will be returned.
    """
    def __init__(
        self,
        *,
        community_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        project_name_pattern: builtins.str = ...,
        owned_by_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["community_id", b"community_id", "owned_by_id", b"owned_by_id", "page_size", b"page_size", "page_token", b"page_token", "project_name_pattern", b"project_name_pattern"]) -> None: ...

global___ListProjectsRequest = ListProjectsRequest

@typing.final
class ListProjectsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListProjectsRequest.page_size], use
    the [next_page_token] as the value
    for the [ListProjectsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    [next_page_token] to continue paging through the results.
    """
    @property
    def projects(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.project_pb2.Project]:
        """List of Project resources."""

    def __init__(
        self,
        *,
        projects: collections.abc.Iterable[yandex.cloud.datasphere.v2.project_pb2.Project] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "projects", b"projects"]) -> None: ...

global___ListProjectsResponse = ListProjectsResponse

@typing.final
class GetUnitBalanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to return the unit balance for."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___GetUnitBalanceRequest = GetUnitBalanceRequest

@typing.final
class GetUnitBalanceResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIT_BALANCE_FIELD_NUMBER: builtins.int
    @property
    def unit_balance(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units available to the project."""

    def __init__(
        self,
        *,
        unit_balance: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["unit_balance", b"unit_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["unit_balance", b"unit_balance"]) -> None: ...

global___GetUnitBalanceResponse = GetUnitBalanceResponse

@typing.final
class SetUnitBalanceRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    UNIT_BALANCE_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to set the unit balance for."""
    @property
    def unit_balance(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units available to the project."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        unit_balance: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["unit_balance", b"unit_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "unit_balance", b"unit_balance"]) -> None: ...

global___SetUnitBalanceRequest = SetUnitBalanceRequest

@typing.final
class SetUnitBalanceMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project which unit balance is set."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___SetUnitBalanceMetadata = SetUnitBalanceMetadata

@typing.final
class ProjectExecutionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    CELL_ID_FIELD_NUMBER: builtins.int
    INPUT_VARIABLES_FIELD_NUMBER: builtins.int
    OUTPUT_VARIABLE_NAMES_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    SPARK_CONNECTOR_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to execute notebook/cell in."""
    notebook_id: builtins.str
    """The path to the executable notebook in the project storage. The maximum string length is 200 characters.

    To get the path, right-click on the notebook in JupyterLab and select `Copy path`.
    """
    cell_id: builtins.str
    """ID of the cell to execute.
    Deprecated
    """
    spec: builtins.str
    """Specification of the VM"""
    spark_connector_id: builtins.str
    """ID of the Spark Connector"""
    @property
    def input_variables(self) -> google.protobuf.struct_pb2.Struct:
        """Values of input variables. Input variables will be available in the project as environment variables."""

    @property
    def output_variable_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of output variables."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_id: builtins.str = ...,
        cell_id: builtins.str = ...,
        input_variables: google.protobuf.struct_pb2.Struct | None = ...,
        output_variable_names: collections.abc.Iterable[builtins.str] | None = ...,
        spec: builtins.str = ...,
        spark_connector_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cell_id", b"cell_id", "input_variables", b"input_variables", "notebook_id", b"notebook_id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_id", b"cell_id", "input_variables", b"input_variables", "notebook_id", b"notebook_id", "output_variable_names", b"output_variable_names", "project_id", b"project_id", "spark_connector_id", b"spark_connector_id", "spec", b"spec", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["notebook_id", "cell_id"] | None: ...

global___ProjectExecutionRequest = ProjectExecutionRequest

@typing.final
class ProjectExecutionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    CELL_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project in which notebook is being executed."""
    notebook_id: builtins.str
    """ID of the notebook that is being executed"""
    cell_id: builtins.str
    """ID of the cell that is being executed"""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_id: builtins.str = ...,
        cell_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["cell_id", b"cell_id", "notebook_id", b"notebook_id", "target", b"target"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_id", b"cell_id", "notebook_id", b"notebook_id", "project_id", b"project_id", "target", b"target"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["target", b"target"]) -> typing.Literal["notebook_id", "cell_id"] | None: ...

global___ProjectExecutionMetadata = ProjectExecutionMetadata

@typing.final
class ProjectExecutionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECKPOINT_ID_FIELD_NUMBER: builtins.int
    OUTPUT_VARIABLES_FIELD_NUMBER: builtins.int
    EXECUTION_STATUS_FIELD_NUMBER: builtins.int
    checkpoint_id: builtins.str
    """ID of the checkpoint resulting from the execution.
    <project_id>/checkpoint/<uuid>
    """
    execution_status: global___ExecutionStatus.ValueType
    """Execution final status."""
    @property
    def output_variables(self) -> google.protobuf.struct_pb2.Struct:
        """Values of output variables resulting from the execution.
        Deprecated
        """

    def __init__(
        self,
        *,
        checkpoint_id: builtins.str = ...,
        output_variables: google.protobuf.struct_pb2.Struct | None = ...,
        execution_status: global___ExecutionStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["output_variables", b"output_variables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["checkpoint_id", b"checkpoint_id", "execution_status", b"execution_status", "output_variables", b"output_variables"]) -> None: ...

global___ProjectExecutionResponse = ProjectExecutionResponse

@typing.final
class CellOutputsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    CELL_ID_FIELD_NUMBER: builtins.int
    CHECKPOINT_ID_FIELD_NUMBER: builtins.int
    START_AT_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project to return cell outputs for."""
    cell_id: builtins.str
    """ID of the cell to return outputs for."""
    checkpoint_id: builtins.str
    """ID of the checkpoint to return cell outputs for."""
    @property
    def start_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Timestamp from which to return outputs."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        cell_id: builtins.str = ...,
        checkpoint_id: builtins.str = ...,
        start_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["start_at", b"start_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cell_id", b"cell_id", "checkpoint_id", b"checkpoint_id", "project_id", b"project_id", "start_at", b"start_at"]) -> None: ...

global___CellOutputsRequest = CellOutputsRequest

@typing.final
class CellOutputsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUTS_FIELD_NUMBER: builtins.int
    @property
    def outputs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of outputs."""

    def __init__(
        self,
        *,
        outputs: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["outputs", b"outputs"]) -> None: ...

global___CellOutputsResponse = CellOutputsResponse

@typing.final
class GetStateVariablesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    NOTEBOOK_ID_FIELD_NUMBER: builtins.int
    VARIABLE_NAMES_FIELD_NUMBER: builtins.int
    CHECKPOINT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project, for which to return state variables."""
    notebook_id: builtins.str
    """ID of the notebook, for which to return state variables."""
    checkpoint_id: builtins.str
    """ID of the checkpoint, for which to return state variables."""
    @property
    def variable_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Names of variables to return."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        notebook_id: builtins.str = ...,
        variable_names: collections.abc.Iterable[builtins.str] | None = ...,
        checkpoint_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["checkpoint_id", b"checkpoint_id", "notebook_id", b"notebook_id", "project_id", b"project_id", "variable_names", b"variable_names"]) -> None: ...

global___GetStateVariablesRequest = GetStateVariablesRequest

@typing.final
class GetStateVariablesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VARIABLES_FIELD_NUMBER: builtins.int
    @property
    def variables(self) -> google.protobuf.struct_pb2.Struct:
        """Values of the specified variables."""

    def __init__(
        self,
        *,
        variables: google.protobuf.struct_pb2.Struct | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["variables", b"variables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["variables", b"variables"]) -> None: ...

global___GetStateVariablesResponse = GetStateVariablesResponse

@typing.final
class SetProjectAccessBindingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project which access bindings are set."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___SetProjectAccessBindingsMetadata = SetProjectAccessBindingsMetadata

@typing.final
class UpdateProjectAccessBindingsMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project which access bindings are updated."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___UpdateProjectAccessBindingsMetadata = UpdateProjectAccessBindingsMetadata

@typing.final
class AddResourceToProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType
    resource_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "resource_id", b"resource_id", "resource_type", b"resource_type"]) -> None: ...

global___AddResourceToProjectRequest = AddResourceToProjectRequest

@typing.final
class RemoveResourceFromProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    RESOURCE_TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType
    resource_id: builtins.str
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        resource_type: yandex.cloud.datasphere.v2.resource_types_pb2.ResourceType.ValueType = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "resource_id", b"resource_id", "resource_type", b"resource_type"]) -> None: ...

global___RemoveResourceFromProjectRequest = RemoveResourceFromProjectRequest

@typing.final
class GetProjectRestrictionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project."""
    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id"]) -> None: ...

global___GetProjectRestrictionsRequest = GetProjectRestrictionsRequest

@typing.final
class SetProjectRestrictionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROJECT_ID_FIELD_NUMBER: builtins.int
    RESTRICTIONS_FIELD_NUMBER: builtins.int
    project_id: builtins.str
    """ID of the project."""
    @property
    def restrictions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.datasphere.v2.restrictions_pb2.Restriction]:
        """List of restrictions to set."""

    def __init__(
        self,
        *,
        project_id: builtins.str = ...,
        restrictions: collections.abc.Iterable[yandex.cloud.datasphere.v2.restrictions_pb2.Restriction] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["project_id", b"project_id", "restrictions", b"restrictions"]) -> None: ...

global___SetProjectRestrictionsRequest = SetProjectRestrictionsRequest



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/organizationmanager/v1/organization_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.organizationmanager.v1 import organization_pb2 as yandex_dot_cloud_dot_organizationmanager_dot_v1_dot_organization__pb2
from yandex.cloud.access import access_pb2 as yandex_dot_cloud_dot_access_dot_access__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>yandex/cloud/organizationmanager/v1/organization_service.proto\x12#yandex.cloud.organizationmanager.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x36yandex/cloud/organizationmanager/v1/organization.proto\x1a yandex/cloud/access/access.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"?\n\x16GetOrganizationRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"u\n\x18ListOrganizationsRequest\x12\x1d\n\tpage_size\x18\x01 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x02 \x01(\tB\n\x8a\xc8\x31\x06<=2000\x12\x1a\n\x06\x66ilter\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"~\n\x19ListOrganizationsResponse\x12H\n\rorganizations\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.organizationmanager.v1.Organization\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xaa\x03\n\x19UpdateOrganizationRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x32\n\x04name\x18\x03 \x01(\tB$\xf2\xc7\x31 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x18\n\x05title\x18\x05 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x97\x01\n\x06labels\x18\x06 \x03(\x0b\x32J.yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest.LabelsEntryB;\xf2\xc7\x31\x0b[-_0-9a-z]*\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xb2\xc8\x31\x18\x12\x10[a-z][-_0-9a-z]*\x1a\x04\x31-63\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"5\n\x1aUpdateOrganizationMetadata\x12\x17\n\x0forganization_id\x18\x01 \x01(\t\"\x89\x01\n!ListOrganizationOperationsRequest\x12%\n\x0forganization_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"t\n\"ListOrganizationOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xa0\x0c\n\x13OrganizationService\x12\xb7\x01\n\x03Get\x12;.yandex.cloud.organizationmanager.v1.GetOrganizationRequest\x1a\x31.yandex.cloud.organizationmanager.v1.Organization\"@\x82\xd3\xe4\x93\x02:\x12\x38/organization-manager/v1/organizations/{organization_id}\x12\xb5\x01\n\x04List\x12=.yandex.cloud.organizationmanager.v1.ListOrganizationsRequest\x1a>.yandex.cloud.organizationmanager.v1.ListOrganizationsResponse\".\x82\xd3\xe4\x93\x02(\x12&/organization-manager/v1/organizations\x12\xde\x01\n\x06Update\x12>.yandex.cloud.organizationmanager.v1.UpdateOrganizationRequest\x1a!.yandex.cloud.operation.Operation\"q\xb2\xd2**\n\x1aUpdateOrganizationMetadata\x12\x0cOrganization\x82\xd3\xe4\x93\x02=28/organization-manager/v1/organizations/{organization_id}:\x01*\x12\xee\x01\n\x0eListOperations\x12\x46.yandex.cloud.organizationmanager.v1.ListOrganizationOperationsRequest\x1aG.yandex.cloud.organizationmanager.v1.ListOrganizationOperationsResponse\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/organization-manager/v1/organizations/{organization_id}/operations\x12\xc6\x01\n\x12ListAccessBindings\x12..yandex.cloud.access.ListAccessBindingsRequest\x1a/.yandex.cloud.access.ListAccessBindingsResponse\"O\x82\xd3\xe4\x93\x02I\x12G/organization-manager/v1/organizations/{resource_id}:listAccessBindings\x12\xf6\x01\n\x11SetAccessBindings\x12-.yandex.cloud.access.SetAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x8e\x01\xb2\xd2*9\n access.SetAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02K\"F/organization-manager/v1/organizations/{resource_id}:setAccessBindings:\x01*\x12\x82\x02\n\x14UpdateAccessBindings\x12\x30.yandex.cloud.access.UpdateAccessBindingsRequest\x1a!.yandex.cloud.operation.Operation\"\x94\x01\xb2\xd2*<\n#access.UpdateAccessBindingsMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02N\"I/organization-manager/v1/organizations/{resource_id}:updateAccessBindings:\x01*B\x86\x01\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanagerb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.organizationmanager.v1.organization_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\'yandex.cloud.api.organizationmanager.v1Z[github.com/yandex-cloud/go-genproto/yandex/cloud/organizationmanager/v1;organizationmanager'
  _GETORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _GETORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _LISTORGANIZATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTORGANIZATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\212\3101\006<=1000'
  _UPDATEORGANIZATIONREQUEST_LABELSENTRY._options = None
  _UPDATEORGANIZATIONREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['name']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['name']._serialized_options = b'\362\3071 |[a-z]([-a-z0-9]{0,61}[a-z0-9])?'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['description']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['description']._serialized_options = b'\212\3101\005<=256'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['title']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['title']._serialized_options = b'\212\3101\005<=256'
  _UPDATEORGANIZATIONREQUEST.fields_by_name['labels']._options = None
  _UPDATEORGANIZATIONREQUEST.fields_by_name['labels']._serialized_options = b'\362\3071\013[-_0-9a-z]*\202\3101\004<=64\212\3101\004<=63\262\3101\030\022\020[a-z][-_0-9a-z]*\032\0041-63'
  _LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['organization_id']._options = None
  _LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['organization_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['page_size']._options = None
  _LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTORGANIZATIONOPERATIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _ORGANIZATIONSERVICE.methods_by_name['Get']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002:\0228/organization-manager/v1/organizations/{organization_id}'
  _ORGANIZATIONSERVICE.methods_by_name['List']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002(\022&/organization-manager/v1/organizations'
  _ORGANIZATIONSERVICE.methods_by_name['Update']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['Update']._serialized_options = b'\262\322**\n\032UpdateOrganizationMetadata\022\014Organization\202\323\344\223\002=28/organization-manager/v1/organizations/{organization_id}:\001*'
  _ORGANIZATIONSERVICE.methods_by_name['ListOperations']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['ListOperations']._serialized_options = b'\202\323\344\223\002E\022C/organization-manager/v1/organizations/{organization_id}/operations'
  _ORGANIZATIONSERVICE.methods_by_name['ListAccessBindings']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['ListAccessBindings']._serialized_options = b'\202\323\344\223\002I\022G/organization-manager/v1/organizations/{resource_id}:listAccessBindings'
  _ORGANIZATIONSERVICE.methods_by_name['SetAccessBindings']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['SetAccessBindings']._serialized_options = b'\262\322*9\n access.SetAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002K\"F/organization-manager/v1/organizations/{resource_id}:setAccessBindings:\001*'
  _ORGANIZATIONSERVICE.methods_by_name['UpdateAccessBindings']._options = None
  _ORGANIZATIONSERVICE.methods_by_name['UpdateAccessBindings']._serialized_options = b'\262\322*<\n#access.UpdateAccessBindingsMetadata\022\025google.protobuf.Empty\202\323\344\223\002N\"I/organization-manager/v1/organizations/{resource_id}:updateAccessBindings:\001*'
  _globals['_GETORGANIZATIONREQUEST']._serialized_start=362
  _globals['_GETORGANIZATIONREQUEST']._serialized_end=425
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_start=427
  _globals['_LISTORGANIZATIONSREQUEST']._serialized_end=544
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_start=546
  _globals['_LISTORGANIZATIONSRESPONSE']._serialized_end=672
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_start=675
  _globals['_UPDATEORGANIZATIONREQUEST']._serialized_end=1101
  _globals['_UPDATEORGANIZATIONREQUEST_LABELSENTRY']._serialized_start=1056
  _globals['_UPDATEORGANIZATIONREQUEST_LABELSENTRY']._serialized_end=1101
  _globals['_UPDATEORGANIZATIONMETADATA']._serialized_start=1103
  _globals['_UPDATEORGANIZATIONMETADATA']._serialized_end=1156
  _globals['_LISTORGANIZATIONOPERATIONSREQUEST']._serialized_start=1159
  _globals['_LISTORGANIZATIONOPERATIONSREQUEST']._serialized_end=1296
  _globals['_LISTORGANIZATIONOPERATIONSRESPONSE']._serialized_start=1298
  _globals['_LISTORGANIZATIONOPERATIONSRESPONSE']._serialized_end=1414
  _globals['_ORGANIZATIONSERVICE']._serialized_start=1417
  _globals['_ORGANIZATIONSERVICE']._serialized_end=2985
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.k8s.v1.node_group_pb2
import yandex.cloud.k8s.v1.node_pb2
import yandex.cloud.k8s.v1.version_pb2
import yandex.cloud.operation.operation_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group to return.
    To get the node group ID use a [NodeGroupService.List] request.
    """
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id"]) -> None: ...

global___GetNodeGroupRequest = GetNodeGroupRequest

@typing.final
class ListNodeGroupsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to list node groups in.
    To get the folder ID use a [yandex.cloud.resourcemanager.v1.FolderService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListNodeGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListNodeGroupsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    The expression must specify:
    1. The field name. Currently you can use filtering only on [NodeGroup.name] field.
    2. An `=` operator.
    3. The value in double quotes (`"`). Must be 3-63 characters long and match the regular expression `[a-z][-a-z0-9]{1,61}[a-z0-9]`.
    """
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNodeGroupsRequest = ListNodeGroupsRequest

@typing.final
class ListNodeGroupsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUPS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNodeGroupsRequest.page_size], use
    the `next_page_token` as the value
    for the [ListNodeGroupsRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def node_groups(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_group_pb2.NodeGroup]:
        """List of node groups."""

    def __init__(
        self,
        *,
        node_groups: collections.abc.Iterable[yandex.cloud.k8s.v1.node_group_pb2.NodeGroup] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "node_groups", b"node_groups"]) -> None: ...

global___ListNodeGroupsResponse = ListNodeGroupsResponse

@typing.final
class ListNodeGroupNodesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group to list.
    To get the node group ID use a [NodeGroupService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size],
    the service returns a [ListNodeGroupsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListNodeGroupNodesResponse.next_page_token] returned by a previous list request.
    """
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNodeGroupNodesRequest = ListNodeGroupNodesRequest

@typing.final
class ListNodeGroupNodesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNodeGroupNodesRequest.page_size], use
    the `next_page_token` as the value
    for the [ListNodeGroupNodesRequest.page_token] query parameter
    in the next list request. Each subsequent list request will have its own
    `next_page_token` to continue paging through the results.
    """
    @property
    def nodes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_pb2.Node]:
        """List of nodes."""

    def __init__(
        self,
        *,
        nodes: collections.abc.Iterable[yandex.cloud.k8s.v1.node_pb2.Node] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "nodes", b"nodes"]) -> None: ...

global___ListNodeGroupNodesResponse = ListNodeGroupNodesResponse

@typing.final
class DeleteNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group to delete.
    To get node group ID use a [NodeGroupService.List] request.
    """
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id"]) -> None: ...

global___DeleteNodeGroupRequest = DeleteNodeGroupRequest

@typing.final
class DeleteNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group that is being deleted."""
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id"]) -> None: ...

global___DeleteNodeGroupMetadata = DeleteNodeGroupMetadata

@typing.final
class UpdateNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NodeLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NODE_TEMPLATE_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    DEPLOY_POLICY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    ALLOWED_UNSAFE_SYSCTLS_FIELD_NUMBER: builtins.int
    NODE_TAINTS_FIELD_NUMBER: builtins.int
    NODE_LABELS_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group to update.
    To get the node group ID use a [NodeGroupService.List] request.
    """
    name: builtins.str
    """Name of the node group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the node group."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the node group are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs.

        Existing set of `labels` is completely replaced by the provided set.
        """

    @property
    def node_template(self) -> yandex.cloud.k8s.v1.node_pb2.NodeTemplate:
        """Node template for the node group.
        Change may trigger nodes rolling reboot or recreate.
        """

    @property
    def scale_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.ScalePolicy:
        """Scale policy of the node group."""

    @property
    def allocation_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.NodeGroupAllocationPolicy:
        """Allocation policy of the node group by the zones and regions."""

    @property
    def deploy_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.DeployPolicy:
        """Deploy policy according to which the updates are rolled out. If not specified,
        the default is used.
        """

    @property
    def version(self) -> yandex.cloud.k8s.v1.version_pb2.UpdateVersionSpec:
        """Version of Kubernetes components that runs on the nodes."""

    @property
    def maintenance_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.NodeGroupMaintenancePolicy:
        """Maintenance policy of the node group."""

    @property
    def allowed_unsafe_sysctls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Support for unsafe sysctl parameters. For more details see [documentation](https://kubernetes.io/docs/tasks/administer-cluster/sysctl-cluster/)."""

    @property
    def node_taints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_pb2.Taint]:
        """Taints that are applied to the nodes of the node group at creation time."""

    @property
    def node_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels that are assigned to the nodes of the node group at creation time."""

    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        node_template: yandex.cloud.k8s.v1.node_pb2.NodeTemplate | None = ...,
        scale_policy: yandex.cloud.k8s.v1.node_group_pb2.ScalePolicy | None = ...,
        allocation_policy: yandex.cloud.k8s.v1.node_group_pb2.NodeGroupAllocationPolicy | None = ...,
        deploy_policy: yandex.cloud.k8s.v1.node_group_pb2.DeployPolicy | None = ...,
        version: yandex.cloud.k8s.v1.version_pb2.UpdateVersionSpec | None = ...,
        maintenance_policy: yandex.cloud.k8s.v1.node_group_pb2.NodeGroupMaintenancePolicy | None = ...,
        allowed_unsafe_sysctls: collections.abc.Iterable[builtins.str] | None = ...,
        node_taints: collections.abc.Iterable[yandex.cloud.k8s.v1.node_pb2.Taint] | None = ...,
        node_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "deploy_policy", b"deploy_policy", "maintenance_policy", b"maintenance_policy", "node_template", b"node_template", "scale_policy", b"scale_policy", "update_mask", b"update_mask", "version", b"version"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "allowed_unsafe_sysctls", b"allowed_unsafe_sysctls", "deploy_policy", b"deploy_policy", "description", b"description", "labels", b"labels", "maintenance_policy", b"maintenance_policy", "name", b"name", "node_group_id", b"node_group_id", "node_labels", b"node_labels", "node_taints", b"node_taints", "node_template", b"node_template", "scale_policy", b"scale_policy", "update_mask", b"update_mask", "version", b"version"]) -> None: ...

global___UpdateNodeGroupRequest = UpdateNodeGroupRequest

@typing.final
class UpdateNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the Node group that is being updated."""
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id"]) -> None: ...

global___UpdateNodeGroupMetadata = UpdateNodeGroupMetadata

@typing.final
class CreateNodeGroupRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing.final
    class NodeLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    NODE_TEMPLATE_FIELD_NUMBER: builtins.int
    SCALE_POLICY_FIELD_NUMBER: builtins.int
    ALLOCATION_POLICY_FIELD_NUMBER: builtins.int
    DEPLOY_POLICY_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    ALLOWED_UNSAFE_SYSCTLS_FIELD_NUMBER: builtins.int
    NODE_TAINTS_FIELD_NUMBER: builtins.int
    NODE_LABELS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the Kubernetes cluster to create a node group in.
    To get the Kubernetes cluster ID, use a [ClusterService.List] request.
    """
    name: builtins.str
    """Name of the node group.
    The name must be unique within the folder.
    """
    description: builtins.str
    """Description of the node group."""
    version: builtins.str
    """Version of Kubernetes components that runs on the nodes."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Resource labels as `key:value` pairs."""

    @property
    def node_template(self) -> yandex.cloud.k8s.v1.node_pb2.NodeTemplate:
        """Node template for creating the node group."""

    @property
    def scale_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.ScalePolicy:
        """Scale policy of the node group."""

    @property
    def allocation_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.NodeGroupAllocationPolicy:
        """Allocation policy of the node group by the zones and regions."""

    @property
    def deploy_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.DeployPolicy:
        """Deploy policy according to which the updates are rolled out. If not specified,
        the default is used.
        """

    @property
    def maintenance_policy(self) -> yandex.cloud.k8s.v1.node_group_pb2.NodeGroupMaintenancePolicy:
        """Maintenance policy of the node group."""

    @property
    def allowed_unsafe_sysctls(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Support for unsafe sysctl parameters. For more details see [documentation](https://kubernetes.io/docs/tasks/administer-cluster/sysctl-cluster/)."""

    @property
    def node_taints(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.k8s.v1.node_pb2.Taint]:
        """Taints that are applied to the nodes of the node group at creation time."""

    @property
    def node_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels that are assigned to the nodes of the node group at creation time."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        node_template: yandex.cloud.k8s.v1.node_pb2.NodeTemplate | None = ...,
        scale_policy: yandex.cloud.k8s.v1.node_group_pb2.ScalePolicy | None = ...,
        allocation_policy: yandex.cloud.k8s.v1.node_group_pb2.NodeGroupAllocationPolicy | None = ...,
        deploy_policy: yandex.cloud.k8s.v1.node_group_pb2.DeployPolicy | None = ...,
        version: builtins.str = ...,
        maintenance_policy: yandex.cloud.k8s.v1.node_group_pb2.NodeGroupMaintenancePolicy | None = ...,
        allowed_unsafe_sysctls: collections.abc.Iterable[builtins.str] | None = ...,
        node_taints: collections.abc.Iterable[yandex.cloud.k8s.v1.node_pb2.Taint] | None = ...,
        node_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "deploy_policy", b"deploy_policy", "maintenance_policy", b"maintenance_policy", "node_template", b"node_template", "scale_policy", b"scale_policy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["allocation_policy", b"allocation_policy", "allowed_unsafe_sysctls", b"allowed_unsafe_sysctls", "cluster_id", b"cluster_id", "deploy_policy", b"deploy_policy", "description", b"description", "labels", b"labels", "maintenance_policy", b"maintenance_policy", "name", b"name", "node_labels", b"node_labels", "node_taints", b"node_taints", "node_template", b"node_template", "scale_policy", b"scale_policy", "version", b"version"]) -> None: ...

global___CreateNodeGroupRequest = CreateNodeGroupRequest

@typing.final
class CreateNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group that is being created."""
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id"]) -> None: ...

global___CreateNodeGroupMetadata = CreateNodeGroupMetadata

@typing.final
class AutoUpgradeNodeGroupMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group that is being auto upgraded."""
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["node_group_id", b"node_group_id"]) -> None: ...

global___AutoUpgradeNodeGroupMetadata = AutoUpgradeNodeGroupMetadata

@typing.final
class ListNodeGroupOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    node_group_id: builtins.str
    """ID of the node group to list operations for."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than [page_size], the service returns a [ListNodeGroupOperationsResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    Default value: 100.
    """
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    [ListNodeGroupOperationsResponse.next_page_token] returned by a previous list request.
    """
    filter: builtins.str
    """A filter expression that filters resources listed in the response.
    Currently you can use filtering only on [NodeGroup.name] field.
    """
    def __init__(
        self,
        *,
        node_group_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "node_group_id", b"node_group_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListNodeGroupOperationsRequest = ListNodeGroupOperationsRequest

@typing.final
class ListNodeGroupOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListNodeGroupOperationsRequest.page_size], use the `next_page_token` as the value
    for the [ListNodeGroupOperationsRequest.page_token] query parameter in the next list request.
    Each subsequent list request will have its own `next_page_token` to continue paging through the results.
    """
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified node group."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListNodeGroupOperationsResponse = ListNodeGroupOperationsResponse



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/ai/assistants/v1/searchindex/common.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/ai/assistants/v1/searchindex/common.proto\x12)yandex.cloud.ai.assistants.v1.searchindex\"U\n\x16StaticChunkingStrategy\x12\x1d\n\x15max_chunk_size_tokens\x18\x01 \x01(\x03\x12\x1c\n\x14\x63hunk_overlap_tokens\x18\x02 \x01(\x03\"|\n\x10\x43hunkingStrategy\x12\\\n\x0fstatic_strategy\x18\x01 \x01(\x0b\x32\x41.yandex.cloud.ai.assistants.v1.searchindex.StaticChunkingStrategyH\x00\x42\n\n\x08StrategyB\x8a\x01\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindexb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.ai.assistants.v1.searchindex.common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n-yandex.cloud.api.ai.assistants.v1.searchindexZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/ai/assistants/v1/searchindex;searchindex'
  _globals['_STATICCHUNKINGSTRATEGY']._serialized_start=101
  _globals['_STATICCHUNKINGSTRATEGY']._serialized_end=186
  _globals['_CHUNKINGSTRATEGY']._serialized_start=188
  _globals['_CHUNKINGSTRATEGY']._serialized_end=312
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.project_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class CreateProjectRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    CONNECTION_ID_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    FILTERS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """project name"""
    connection_id: builtins.str
    """id of connection the project should belong too"""
    description: builtins.str
    """project description"""
    @property
    def filters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.project_pb2.FieldFilter]:
        """project filters"""

    def __init__(
        self,
        *,
        name: builtins.str = ...,
        connection_id: builtins.str = ...,
        description: builtins.str = ...,
        filters: collections.abc.Iterable[yandex.cloud.speechsense.v1.project_pb2.FieldFilter] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["connection_id", b"connection_id", "description", b"description", "filters", b"filters", "name", b"name"]) -> None: ...

global___CreateProjectRequest = CreateProjectRequest

@typing.final
class CreateProjectMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    id: builtins.str
    def __init__(
        self,
        *,
        id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["id", b"id"]) -> None: ...

global___CreateProjectMetadata = CreateProjectMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.operation.operation_pb2
import yandex.cloud.serverless.eventrouter.v1.rule_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule to return."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___GetRuleRequest = GetRuleRequest

@typing.final
class ListRulesRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUS_ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to list rules in."""
    folder_id: builtins.str
    """ID of the folder to list rules in."""
    page_size: builtins.int
    """The maximum number of results per response."""
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    `next_page_token` returned by a previous list request.
    """
    filter: builtins.str
    """Supported fields for filter:
      name
      created_at
    """
    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        folder_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["bus_id", b"bus_id", "container_id", b"container_id", "folder_id", b"folder_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "container_id", b"container_id", "filter", b"filter", "folder_id", b"folder_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["container_id", b"container_id"]) -> typing.Literal["bus_id", "folder_id"] | None: ...

global___ListRulesRequest = ListRulesRequest

@typing.final
class ListRulesResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list of rules."""
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Rule]:
        """List of rules."""

    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Rule] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "rules", b"rules"]) -> None: ...

global___ListRulesResponse = ListRulesResponse

@typing.final
class CreateRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    BUS_ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    bus_id: builtins.str
    """ID of the bus to create a rule for."""
    name: builtins.str
    """Name of the rule."""
    description: builtins.str
    """Description of the rule."""
    deletion_protection: builtins.bool
    """Flag that disallow deletion of the rule."""
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Labels for the rule."""

    @property
    def filter(self) -> yandex.cloud.serverless.eventrouter.v1.rule_pb2.Filter:
        """Filter for the rule."""

    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Target]:
        """Targets for the rule."""

    def __init__(
        self,
        *,
        bus_id: builtins.str = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        filter: yandex.cloud.serverless.eventrouter.v1.rule_pb2.Filter | None = ...,
        targets: collections.abc.Iterable[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Target] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "deletion_protection", b"deletion_protection", "description", b"description", "filter", b"filter", "labels", b"labels", "name", b"name", "targets", b"targets"]) -> None: ...

global___CreateRuleRequest = CreateRuleRequest

@typing.final
class CreateRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    BUS_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule that is being created."""
    bus_id: builtins.str
    """ID of the bus that the rule belongs to."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
        bus_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["bus_id", b"bus_id", "rule_id", b"rule_id"]) -> None: ...

global___CreateRuleMetadata = CreateRuleMetadata

@typing.final
class UpdateRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    RULE_ID_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    TARGETS_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule to update."""
    name: builtins.str
    """New name of the rule."""
    description: builtins.str
    """New description of the rule."""
    deletion_protection: builtins.bool
    """New flag that disallow deletion of the rule."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the rule are going to be updated."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """New labels for the rule."""

    @property
    def filter(self) -> yandex.cloud.serverless.eventrouter.v1.rule_pb2.Filter:
        """New filter for the rule."""

    @property
    def targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Target]:
        """New targets for the rule."""

    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        filter: yandex.cloud.serverless.eventrouter.v1.rule_pb2.Filter | None = ...,
        targets: collections.abc.Iterable[yandex.cloud.serverless.eventrouter.v1.rule_pb2.Target] | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["filter", b"filter", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["deletion_protection", b"deletion_protection", "description", b"description", "filter", b"filter", "labels", b"labels", "name", b"name", "rule_id", b"rule_id", "targets", b"targets", "update_mask", b"update_mask"]) -> None: ...

global___UpdateRuleRequest = UpdateRuleRequest

@typing.final
class UpdateRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule that is being updated."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___UpdateRuleMetadata = UpdateRuleMetadata

@typing.final
class DeleteRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule to delete."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___DeleteRuleRequest = DeleteRuleRequest

@typing.final
class DeleteRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule that is being deleted."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___DeleteRuleMetadata = DeleteRuleMetadata

@typing.final
class ListRuleOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule to list operations for."""
    page_size: builtins.int
    """The maximum number of results per response."""
    page_token: builtins.str
    """Page token. To get the next page of results, set `page_token` to the
    `next_page_token` returned by a previous list request.
    """
    filter: builtins.str
    """Supported attributes for filter:
      description
      created_at
      modified_at
      created_by
      done
    """
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["filter", b"filter", "page_size", b"page_size", "page_token", b"page_token", "rule_id", b"rule_id"]) -> None: ...

global___ListRuleOperationsRequest = ListRuleOperationsRequest

@typing.final
class ListRuleOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """Token for getting the next page of the list of operations."""
    @property
    def operations(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.operation.operation_pb2.Operation]:
        """List of operations for the specified rule."""

    def __init__(
        self,
        *,
        operations: collections.abc.Iterable[yandex.cloud.operation.operation_pb2.Operation] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "operations", b"operations"]) -> None: ...

global___ListRuleOperationsResponse = ListRuleOperationsResponse

@typing.final
class EnableRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule to enable."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___EnableRuleRequest = EnableRuleRequest

@typing.final
class EnableRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule that is being enabled."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___EnableRuleMetadata = EnableRuleMetadata

@typing.final
class DisableRuleRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule to disable."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___DisableRuleRequest = DisableRuleRequest

@typing.final
class DisableRuleMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULE_ID_FIELD_NUMBER: builtins.int
    rule_id: builtins.str
    """ID of the rule that is being disabled."""
    def __init__(
        self,
        *,
        rule_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["rule_id", b"rule_id"]) -> None: ...

global___DisableRuleMetadata = DisableRuleMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class LongRunningRecognitionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    AUDIO_FIELD_NUMBER: builtins.int
    @property
    def config(self) -> global___RecognitionConfig: ...
    @property
    def audio(self) -> global___RecognitionAudio: ...
    def __init__(
        self,
        *,
        config: global___RecognitionConfig | None = ...,
        audio: global___RecognitionAudio | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio", b"audio", "config", b"config"]) -> None: ...

global___LongRunningRecognitionRequest = LongRunningRecognitionRequest

@typing.final
class LongRunningRecognitionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpeechRecognitionResult]: ...
    def __init__(
        self,
        *,
        chunks: collections.abc.Iterable[global___SpeechRecognitionResult] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chunks", b"chunks"]) -> None: ...

global___LongRunningRecognitionResponse = LongRunningRecognitionResponse

@typing.final
class StreamingRecognitionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONFIG_FIELD_NUMBER: builtins.int
    AUDIO_CONTENT_FIELD_NUMBER: builtins.int
    audio_content: builtins.bytes
    @property
    def config(self) -> global___RecognitionConfig: ...
    def __init__(
        self,
        *,
        config: global___RecognitionConfig | None = ...,
        audio_content: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio_content", b"audio_content", "config", b"config", "streaming_request", b"streaming_request"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio_content", b"audio_content", "config", b"config", "streaming_request", b"streaming_request"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["streaming_request", b"streaming_request"]) -> typing.Literal["config", "audio_content"] | None: ...

global___StreamingRecognitionRequest = StreamingRecognitionRequest

@typing.final
class StreamingRecognitionResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHUNKS_FIELD_NUMBER: builtins.int
    @property
    def chunks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpeechRecognitionChunk]: ...
    def __init__(
        self,
        *,
        chunks: collections.abc.Iterable[global___SpeechRecognitionChunk] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chunks", b"chunks"]) -> None: ...

global___StreamingRecognitionResponse = StreamingRecognitionResponse

@typing.final
class RecognitionAudio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    URI_FIELD_NUMBER: builtins.int
    content: builtins.bytes
    uri: builtins.str
    def __init__(
        self,
        *,
        content: builtins.bytes = ...,
        uri: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["audio_source", b"audio_source", "content", b"content", "uri", b"uri"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["audio_source", b"audio_source", "content", b"content", "uri", b"uri"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["audio_source", b"audio_source"]) -> typing.Literal["content", "uri"] | None: ...

global___RecognitionAudio = RecognitionAudio

@typing.final
class RecognitionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SPECIFICATION_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    @property
    def specification(self) -> global___RecognitionSpec: ...
    def __init__(
        self,
        *,
        specification: global___RecognitionSpec | None = ...,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["specification", b"specification"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "specification", b"specification"]) -> None: ...

global___RecognitionConfig = RecognitionConfig

@typing.final
class RecognitionSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _AudioEncoding:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _AudioEncodingEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[RecognitionSpec._AudioEncoding.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        AUDIO_ENCODING_UNSPECIFIED: RecognitionSpec._AudioEncoding.ValueType  # 0
        LINEAR16_PCM: RecognitionSpec._AudioEncoding.ValueType  # 1
        """16-bit signed little-endian (Linear PCM)"""
        OGG_OPUS: RecognitionSpec._AudioEncoding.ValueType  # 2
        MP3: RecognitionSpec._AudioEncoding.ValueType  # 3
        """transcription only"""

    class AudioEncoding(_AudioEncoding, metaclass=_AudioEncodingEnumTypeWrapper): ...
    AUDIO_ENCODING_UNSPECIFIED: RecognitionSpec.AudioEncoding.ValueType  # 0
    LINEAR16_PCM: RecognitionSpec.AudioEncoding.ValueType  # 1
    """16-bit signed little-endian (Linear PCM)"""
    OGG_OPUS: RecognitionSpec.AudioEncoding.ValueType  # 2
    MP3: RecognitionSpec.AudioEncoding.ValueType  # 3
    """transcription only"""

    AUDIO_ENCODING_FIELD_NUMBER: builtins.int
    SAMPLE_RATE_HERTZ_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    PROFANITY_FILTER_FIELD_NUMBER: builtins.int
    MODEL_FIELD_NUMBER: builtins.int
    PARTIAL_RESULTS_FIELD_NUMBER: builtins.int
    SINGLE_UTTERANCE_FIELD_NUMBER: builtins.int
    AUDIO_CHANNEL_COUNT_FIELD_NUMBER: builtins.int
    RAW_RESULTS_FIELD_NUMBER: builtins.int
    LITERATURE_TEXT_FIELD_NUMBER: builtins.int
    audio_encoding: global___RecognitionSpec.AudioEncoding.ValueType
    sample_rate_hertz: builtins.int
    """8000, 16000, 48000 only for pcm"""
    language_code: builtins.str
    """code in BCP-47"""
    profanity_filter: builtins.bool
    model: builtins.str
    partial_results: builtins.bool
    """If set true, tentative hypotheses may be returned as they become available (final=false flag)
    If false or omitted, only final=true result(s) are returned.
    Makes sense only for StreamingRecognize requests.
    """
    single_utterance: builtins.bool
    audio_channel_count: builtins.int
    """Used only for long running recognize."""
    raw_results: builtins.bool
    """This mark allows disable normalization text"""
    literature_text: builtins.bool
    """Rewrite text in literature style (default: false)"""
    def __init__(
        self,
        *,
        audio_encoding: global___RecognitionSpec.AudioEncoding.ValueType = ...,
        sample_rate_hertz: builtins.int = ...,
        language_code: builtins.str = ...,
        profanity_filter: builtins.bool = ...,
        model: builtins.str = ...,
        partial_results: builtins.bool = ...,
        single_utterance: builtins.bool = ...,
        audio_channel_count: builtins.int = ...,
        raw_results: builtins.bool = ...,
        literature_text: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["audio_channel_count", b"audio_channel_count", "audio_encoding", b"audio_encoding", "language_code", b"language_code", "literature_text", b"literature_text", "model", b"model", "partial_results", b"partial_results", "profanity_filter", b"profanity_filter", "raw_results", b"raw_results", "sample_rate_hertz", b"sample_rate_hertz", "single_utterance", b"single_utterance"]) -> None: ...

global___RecognitionSpec = RecognitionSpec

@typing.final
class SpeechRecognitionChunk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALTERNATIVES_FIELD_NUMBER: builtins.int
    FINAL_FIELD_NUMBER: builtins.int
    END_OF_UTTERANCE_FIELD_NUMBER: builtins.int
    final: builtins.bool
    """This flag shows that the received chunk contains a part of the recognized text that won't be changed."""
    end_of_utterance: builtins.bool
    """This flag shows that the received chunk is the end of an utterance."""
    @property
    def alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpeechRecognitionAlternative]: ...
    def __init__(
        self,
        *,
        alternatives: collections.abc.Iterable[global___SpeechRecognitionAlternative] | None = ...,
        final: builtins.bool = ...,
        end_of_utterance: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alternatives", b"alternatives", "end_of_utterance", b"end_of_utterance", "final", b"final"]) -> None: ...

global___SpeechRecognitionChunk = SpeechRecognitionChunk

@typing.final
class SpeechRecognitionResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALTERNATIVES_FIELD_NUMBER: builtins.int
    CHANNEL_TAG_FIELD_NUMBER: builtins.int
    channel_tag: builtins.int
    @property
    def alternatives(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SpeechRecognitionAlternative]: ...
    def __init__(
        self,
        *,
        alternatives: collections.abc.Iterable[global___SpeechRecognitionAlternative] | None = ...,
        channel_tag: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["alternatives", b"alternatives", "channel_tag", b"channel_tag"]) -> None: ...

global___SpeechRecognitionResult = SpeechRecognitionResult

@typing.final
class SpeechRecognitionAlternative(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    WORDS_FIELD_NUMBER: builtins.int
    text: builtins.str
    confidence: builtins.float
    @property
    def words(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___WordInfo]: ...
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        confidence: builtins.float = ...,
        words: collections.abc.Iterable[global___WordInfo] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "text", b"text", "words", b"words"]) -> None: ...

global___SpeechRecognitionAlternative = SpeechRecognitionAlternative

@typing.final
class WordInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    END_TIME_FIELD_NUMBER: builtins.int
    WORD_FIELD_NUMBER: builtins.int
    CONFIDENCE_FIELD_NUMBER: builtins.int
    word: builtins.str
    confidence: builtins.float
    @property
    def start_time(self) -> google.protobuf.duration_pb2.Duration: ...
    @property
    def end_time(self) -> google.protobuf.duration_pb2.Duration: ...
    def __init__(
        self,
        *,
        start_time: google.protobuf.duration_pb2.Duration | None = ...,
        end_time: google.protobuf.duration_pb2.Duration | None = ...,
        word: builtins.str = ...,
        confidence: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["end_time", b"end_time", "start_time", b"start_time"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["confidence", b"confidence", "end_time", b"end_time", "start_time", b"start_time", "word", b"word"]) -> None: ...

global___WordInfo = WordInfo
